SoarScore
Author: Anne Hoekstra
Description: Track latest tasks for Celje Cup 2020 - XXIX. Državno prvenstvo Slovenije v jadralnem letenju

#### Celje Cup 2020 - XXIX. Državno prvenstvo Slovenije v jadralnem letenju

June 27, 2020 – July 4, 2020
Celje (Slovenia)
Total competition distance: 2489 km

Club Day6 Task5 - 159/361km AAT
Open Day6 Task5 - 226/533km AAT

Competition results on soaringspot.com

Club Day6 Task5 - 159/361km AAT
Club Day5 No task
Club Day4 Task3 - 97/245km AAT
Club Day3 Task2 - 131/370km AAT
Club Day2 Task1 - 148/383km AAT
Club Day1 Practice1 - 59/266km AAT

Open Day6 Task5 - 226/533km AAT
Open Day5 No task
Open Day4 Task3 - 97/245km AAT
Open Day3 Task2 - 183/492km AAT
Open Day2 Task1 - 240/439km AAT
Open Day1 Practice1 - 59/266km AAT

Competition results on soaringspot.com

Tasks contain XML format compliant with XCSoar